# Timer Converter MS
This package converts easily various time formats to miliseconds

## Examples
```python
calculateMilis("10s") return 10000
calculateMilis("1m") return 60000
calculateMilis("1h")  return 3600000
```
You can run the tests using python __init__.py